@@ -4,14 +4,10 @@
 Tools for analyzing UEFI firmware and checking UEFI modules with FwHunt rules
 """
 
-__author__ = "FwHunt team"
-__email__ = "fwhunt@binarly.io"
-__version__ = "2.2.4"
-
 from .uefi_analyzer import UefiAnalyzer, UefiAnalyzerError
+from .uefi_extractor import UefiBinary, UefiExtractor
 from .uefi_scanner import UefiRule, UefiScanner, UefiScannerError
 from .uefi_te import TerseExecutableParser
-from .uefi_extractor import UefiBinary, UefiExtractor
 
 __all__ = [
     "UefiAnalyzer",
